<?php

namespace app\controllers;

use app\commands\Roles;
use app\models\Capadetalle;
use app\models\Clasificadorcomun;
use Yii;
use app\models\Capa;
use app\models\CapaSearch;
use yii\data\ArrayDataProvider;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\Response;

/**
 * CapaController implements the CRUD actions for Capa model.
 */
class CapaController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                    'class'=>AccessControl::classname(),
                    'rules'=>[
                            [
                                    'allow'=>true,
                                    'roles'=>['@']
                            ],
                    ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    public function beforeAction($event)
    {
        if(!Yii::$app->user->isGuest){
            if(Yii::$app->user->identity->Rol!=Roles::Administrador && Yii::$app->user->identity->Rol!=Roles::Registrador){
                return $this->redirect(['site/index']);
            }
        }
        return parent::beforeAction($event);
    }

    /**
     * Lists all Capa models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new CapaSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        $comboTipoCapa = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>4 ])->all();
        $comboTipoCapa = ArrayHelper::map($comboTipoCapa, 'IdClasificadorComun','Nombre' );

        $comboTipoMapa = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>5 ])->all();
        $comboTipoMapa = ArrayHelper::map($comboTipoMapa, 'IdClasificadorComun','Nombre' );

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'comboTipoCapa'=>$comboTipoCapa,
            'comboTipoMapa'=>$comboTipoMapa,
        ]);
    }

    /**
     * Displays a single Capa model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Capa model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Capa();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->IdCapa]);
        } else {
            return $this->render('create', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Capa model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['view', 'id' => $model->IdCapa]);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Capa model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {

        //elminando los detalles de capa
        Capadetalle::deleteAll( 'IdCapa = :idcapa ', [':idcapa' => $id] );

        $this->findModel($id)->delete();



        return $this->redirect(['index']);
    }

    /**
     * Finds the Capa model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Capa the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Capa::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }


    //////////////////////////////////////////////

    public function actionGetcapadetalle(){

        $id = Yii::$app->request->post('id',0);
        $sql= " CALL pResumen(:Id) ";
        $query = Yii::$app->db->createCommand($sql);
        $query->bindValue(':Id', $id );

        $columns=[];
        try {
            $list = $query->queryAll();
            foreach($list[0] as $key=>$value){
                $columns[]=$key."";
            }

        }catch (\Exception $e) {
            $list=[];
        }

        $dataProvider = new ArrayDataProvider([
            'key'=>'Codigo',
            'allModels' => $list,
            'pagination' => [
                'pageSize' => 0,
            ],
        ]);



        echo $this->renderPartial('_resumen', [
            'dataProvider' => $dataProvider,
            'columns' =>$columns,
            'title' => Capa::findOne($id)->idcTipoCapa->Nombre
        ]);


    }




}
