<?php

namespace app\controllers;

use app\commands\Clasificadores\TipoClasificador;
use app\commands\Roles;
use app\models\Tipoclasificadorcomun;
use Yii;
use app\models\Clasificadorcomun;
use app\models\ClasificadorcomunSearch;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\helpers\Inflector;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * ClasificadorcomunController implements the CRUD actions for Clasificadorcomun model.
 */
class ClasificadorcomunController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                    'class'=>AccessControl::classname(),
                    'rules'=>[
                            [
                                    'allow'=>true,
                                    'roles'=>['@']
                            ],
                    ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    public function beforeAction($event)
    {
        if(!Yii::$app->user->isGuest){
            if(Yii::$app->user->identity->Rol!=Roles::Administrador){
                return $this->redirect(['site/index']);
            }
        }
        return parent::beforeAction($event);
    }

    /**
     * Lists all Clasificadorcomun models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new ClasificadorcomunSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        $comboTipoClasificador = Tipoclasificadorcomun::find()->all();
        $comboTipoClasificador = ArrayHelper::map($comboTipoClasificador,'IdTipoClasificadorComun','Descripcion'  );

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'comboTipoClasificador'=>$comboTipoClasificador
        ]);
    }

    /**
     * Displays a single Clasificadorcomun model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Clasificadorcomun model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Clasificadorcomun();

        if ($model->load(Yii::$app->request->post()) ) {

            $model->Abreviacion = Inflector::camelize( $model->Nombre );
            $model->save();
            return $this->redirect(['view', 'id' => $model->IdClasificadorComun]);
        } else {

            $comboTipoClasificador = Tipoclasificadorcomun::find()->all();
            $comboTipoClasificador = ArrayHelper::map($comboTipoClasificador,'IdTipoClasificadorComun','Descripcion'  );



            return $this->render('create', [
                'model' => $model,
                'comboTipoClasificador'=>$comboTipoClasificador
            ]);
        }
    }

    /**
     * Updates an existing Clasificadorcomun model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()  ) )  {

            $model->Abreviacion = Inflector::camelize( $model->Nombre );
            $model->save();

            return $this->redirect(['view', 'id' => $model->IdClasificadorComun]);
        } else {

            $comboTipoClasificador = Tipoclasificadorcomun::find()->all();
            $comboTipoClasificador = ArrayHelper::map($comboTipoClasificador,'IdTipoClasificadorComun','Descripcion'  );

            return $this->render('update', [
                'model' => $model,
                'comboTipoClasificador'=>$comboTipoClasificador,
            ]);
        }
    }

    /**
     * Deletes an existing Clasificadorcomun model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        try{
            $this->findModel($id)->delete();
            Yii::$app->session->setFlash('success', " El registro fue Eliminado.");
        }catch (\Exception $e) {

            Yii::$app->session->setFlash('danger', "No se pudo Eliminar , por que esta siendo usado por otro registro.");

        }


        return $this->redirect(['index']);
    }

    /**
     * Finds the Clasificadorcomun model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Clasificadorcomun the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Clasificadorcomun::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
