<?php

namespace app\controllers;

use app\commands\Roles;
use app\models\Persona;
use Yii;
use app\models\Empresa;
use app\models\EmpresaSearch;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * EmpresaController implements the CRUD actions for Empresa model.
 */
class EmpresaController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                'class'=>AccessControl::classname(),
                'rules'=>[
                    [
                        'allow'=>true,
                        'roles'=>['@']
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    public function beforeAction($event)
    {
        if(!Yii::$app->user->isGuest){
            if(Yii::$app->user->identity->Rol!=Roles::Administrador){
                return $this->redirect(['site/index']);
            }
        }
        return parent::beforeAction($event);
    }

    /**
     * Lists all Empresa models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new EmpresaSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);


        $persona = Persona::find()
                ->innerJoin('empresa','empresa.IdRepresentanteLegal=persona.IdPersona')
                ->Where( ['!=','persona.IdPersona',1] )
                ->andWhere(['persona.Activo'=>1])->all();

        $comboPersonas = ArrayHelper::map($persona, 'IdPersona', function($mod){
            return $mod->Nombres." ".$mod->Apellidos;
        });

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'comboPersonas' =>$comboPersonas
        ]);
    }

    /**
     * Displays a single Empresa model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Empresa model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Empresa();



        if ( $model->load(Yii::$app->request->post()) ) {


              $model->IdCreadoPor = Yii::$app->user->id;
              $model->FechaCreacion = date("Y-m-d H:i:s");
              $model->save();


            return $this->redirect(['view', 'id' => $model->IdEmpresa]);
        } else {
            $persona = Persona::find()->Where( ['!=','IdPersona',1] )->andWhere(['Activo'=>1])->all();
            $comboPersonas = ArrayHelper::map($persona, 'IdPersona', function($mod){
                    return $mod->Nombres." ".$mod->Apellidos;
            });

            return $this->render('create', [
                'model' => $model,
                'comboPersonas' =>$comboPersonas
            ]);
        }
    }

    /**
     * Updates an existing Empresa model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) ) {

            $model->IdModificadoPor = Yii::$app->user->id;
            $model->FechaModificacion = date("Y-m-d H:i:s");
            $model->save();
            return $this->redirect(['view', 'id' => $model->IdEmpresa]);

        } else {

            $persona = Persona::find()->Where( ['!=','IdPersona',1] )->andWhere(['Activo'=>1])->all();
            $comboPersonas = ArrayHelper::map($persona, 'IdPersona', function($mod){
                return $mod->Nombres." ".$mod->Apellidos;
            });

            return $this->render('update', [
                'model' => $model,
                'comboPersonas' =>$comboPersonas
            ]);
        }
    }

    /**
     * Deletes an existing Empresa model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        //$this->findModel($id)->delete();
        $model = $this->findModel($id);
        $model->IdModificadoPor = Yii::$app->user->id;
        $model->FechaModificacion = date("Y-m-d H:i:s");
        $model->Activo = false;
        $model->save();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Empresa model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Empresa the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Empresa::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
