<?php

namespace app\controllers;

use app\commands\Roles;
use app\models\Persona;
use app\models\UserLogin;
use Yii;
use app\models\User;
use app\models\UserSearch;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * UserController implements the CRUD actions for User model.
 */
class UserController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                    'class'=>AccessControl::classname(),
                    'rules'=>[
                            [
                                    'allow'=>true,
                                    'roles'=>['@']
                            ],
                    ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    public function beforeAction($event)
    {
        if(!Yii::$app->user->isGuest){
            if(Yii::$app->user->identity->Rol!=Roles::Administrador){
                return $this->redirect(['site/index']);
            }
        }
        return parent::beforeAction($event);
    }

    /**
     * Lists all User models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new UserSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single User model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new User model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new User();
        $userLogin = new UserLogin();

        $errores = null;
        if ( $model->load(Yii::$app->request->post())  &&  $userLogin->load( Yii::$app->request->post() )   ) {

            $user = user::find()->where([ "username"=>$userLogin->username ])->one();
            if( is_null($user) ){
                $model->IdCreadoPor = Yii::$app->user->id;
                $model->FechaCreacion = date("Y-m-d H:i:s");
                $model->username = $userLogin->username;
                $model->setPassword( $userLogin->password );
                $model->Activo=true;
                $model->generateAuthKey();

                $model->save();
                return $this->redirect(['view', 'id' => $model->id]);
            }else{
                $errores = " El Username Ya Existe.";
            }


        }


        $comboPersona =  Persona::find()->leftJoin('user','persona.IdPersona=user.IdPersona')->where('user.IdPersona IS NULL')->all();
        $comboPersona = ArrayHelper::map( $comboPersona, 'IdPersona',function($mod){
                return $mod->Nombres." ".$mod->Apellidos;
        });


        if( !empty($errores) ){
            Yii::$app->session->setFlash('danger', $errores );
        }
        return $this->render('create', [
                'model' => $model,
                'userLogin'=> $userLogin,
                'comboPersona' => $comboPersona,
        ]);

    }

    /**
     * Updates an existing User model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $userLogin = new UserLogin();

        if (  $model->load(Yii::$app->request->post()) &&  $userLogin->load(Yii::$app->request->post()) ) {

            $model->IdModificadoPor = Yii::$app->user->id;
            $model->FechaModificacion = date("Y-m-d H:i:s");
            $model->setPassword( $userLogin->password );
            $model->save();
            return $this->redirect(['view', 'id' => $model->id]);

        } else {

            return $this->render('update', [
                'model' => $model,
                'userLogin'=> $userLogin,
            ]);

        }
    }

    /**
     * Deletes an existing User model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        //$this->findModel($id)->delete();
        $model = $this->findModel($id);
        $model->IdModificadoPor = Yii::$app->user->id;
        $model->FechaModificacion = date("Y-m-d H:i:s");
        $model->Activo=false;
        $model->save();

        return $this->redirect(['index']);
    }

    /**
     * Finds the User model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return User the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = User::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
