<?php
App::uses('AppController', 'Controller');
/**
 * Completars Controller
 *
 * @property Completar $Completar
 * @property PaginatorComponent $Paginator
 */
class CompletarsController extends AppController {

/**
 * Components
 *
 * @var array
 */
	public $components = array('Paginator');

/**
 * index method
 *
 * @return void
 */
	public function index() {
		$this->Completar->recursive = 0;
		$this->set('completars', $this->Paginator->paginate());
	}

/**
 * view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function view($id = null) {
		if (!$this->Completar->exists($id)) {
			throw new NotFoundException(__('Invalid completar'));
		}
		$options = array('conditions' => array('Completar.' . $this->Completar->primaryKey => $id));
		$this->set('completar', $this->Completar->find('first', $options));
	}

/**
 * add method
 *
 * @return void
 */
	public function add() {
		if ($this->request->is('post')) {
			$this->Completar->create();
			if ($this->Completar->save($this->request->data)) {
				$this->Session->setFlash(__('The completar has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The completar could not be saved. Please, try again.'));
			}
		}
		$anuncios = $this->Completar->Anuncio->find('list');
		$this->set(compact('anuncios'));
	}

/**
 * edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function edit($id = null) {
		if (!$this->Completar->exists($id)) {
			throw new NotFoundException(__('Invalid completar'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->Completar->save($this->request->data)) {
				$this->Session->setFlash(__('The completar has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The completar could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('Completar.' . $this->Completar->primaryKey => $id));
			$this->request->data = $this->Completar->find('first', $options);
		}
		$anuncios = $this->Completar->Anuncio->find('list');
		$this->set(compact('anuncios'));
	}

/**
 * delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function delete($id = null) {
		$this->Completar->id = $id;
		if (!$this->Completar->exists()) {
			throw new NotFoundException(__('Invalid completar'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->Completar->delete()) {
			$this->Session->setFlash(__('The completar has been deleted.'));
		} else {
			$this->Session->setFlash(__('The completar could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}

/**
 * admin_index method
 *
 * @return void
 */
	public function admin_index() {
		$this->Completar->recursive = 0;
		$this->set('completars', $this->Paginator->paginate());
	}

/**
 * admin_view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_view($id = null) {
		if (!$this->Completar->exists($id)) {
			throw new NotFoundException(__('Invalid completar'));
		}
		$options = array('conditions' => array('Completar.' . $this->Completar->primaryKey => $id));
		$this->set('completar', $this->Completar->find('first', $options));
	}

/**
 * admin_add method
 *
 * @return void
 */
	public function admin_add() {
		if ($this->request->is('post')) {
			$this->Completar->create();
			if ($this->Completar->save($this->request->data)) {
				$this->Session->setFlash(__('The completar has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The completar could not be saved. Please, try again.'));
			}
		}
		$anuncios = $this->Completar->Anuncio->find('list');
		$this->set(compact('anuncios'));
	}

/**
 * admin_edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_edit($id = null) {
		if (!$this->Completar->exists($id)) {
			throw new NotFoundException(__('Invalid completar'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->Completar->save($this->request->data)) {
				$this->Session->setFlash(__('The completar has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The completar could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('Completar.' . $this->Completar->primaryKey => $id));
			$this->request->data = $this->Completar->find('first', $options);
		}
		$anuncios = $this->Completar->Anuncio->find('list');
		$this->set(compact('anuncios'));
	}

/**
 * admin_delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_delete($id = null) {
		$this->Completar->id = $id;
		if (!$this->Completar->exists()) {
			throw new NotFoundException(__('Invalid completar'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->Completar->delete()) {
			$this->Session->setFlash(__('The completar has been deleted.'));
		} else {
			$this->Session->setFlash(__('The completar could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}
}
