<?php
App::uses('AppController', 'Controller');
/**
 * TipoFotos Controller
 *
 * @property TipoFoto $TipoFoto
 * @property PaginatorComponent $Paginator
 */
class TipoFotosController extends AppController {

/**
 * Components
 *
 * @var array
 */
	public $components = array('Paginator');

/**
 * index method
 *
 * @return void
 */
	public function index() {
		$this->TipoFoto->recursive = 0;
		$this->set('tipoFotos', $this->Paginator->paginate());
	}

/**
 * view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function view($id = null) {
		if (!$this->TipoFoto->exists($id)) {
			throw new NotFoundException(__('Invalid tipo foto'));
		}
		$options = array('conditions' => array('TipoFoto.' . $this->TipoFoto->primaryKey => $id));
		$this->set('tipoFoto', $this->TipoFoto->find('first', $options));
	}

/**
 * add method
 *
 * @return void
 */
	public function add() {
		if ($this->request->is('post')) {
			$this->TipoFoto->create();
			if ($this->TipoFoto->save($this->request->data)) {
				$this->Session->setFlash(__('The tipo foto has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The tipo foto could not be saved. Please, try again.'));
			}
		}
	}

/**
 * edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function edit($id = null) {
		if (!$this->TipoFoto->exists($id)) {
			throw new NotFoundException(__('Invalid tipo foto'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->TipoFoto->save($this->request->data)) {
				$this->Session->setFlash(__('The tipo foto has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The tipo foto could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('TipoFoto.' . $this->TipoFoto->primaryKey => $id));
			$this->request->data = $this->TipoFoto->find('first', $options);
		}
	}

/**
 * delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function delete($id = null) {
		$this->TipoFoto->id = $id;
		if (!$this->TipoFoto->exists()) {
			throw new NotFoundException(__('Invalid tipo foto'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->TipoFoto->delete()) {
			$this->Session->setFlash(__('The tipo foto has been deleted.'));
		} else {
			$this->Session->setFlash(__('The tipo foto could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}

/**
 * admin_index method
 *
 * @return void
 */
	public function admin_index() {
		$this->TipoFoto->recursive = 0;
		$this->set('tipoFotos', $this->Paginator->paginate());
	}

/**
 * admin_view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_view($id = null) {
		if (!$this->TipoFoto->exists($id)) {
			throw new NotFoundException(__('Invalid tipo foto'));
		}
		$options = array('conditions' => array('TipoFoto.' . $this->TipoFoto->primaryKey => $id));
		$this->set('tipoFoto', $this->TipoFoto->find('first', $options));
	}

/**
 * admin_add method
 *
 * @return void
 */
	public function admin_add() {
		if ($this->request->is('post')) {
			$this->TipoFoto->create();
			if ($this->TipoFoto->save($this->request->data)) {
				$this->Session->setFlash(__('The tipo foto has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The tipo foto could not be saved. Please, try again.'));
			}
		}
	}

/**
 * admin_edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_edit($id = null) {
		if (!$this->TipoFoto->exists($id)) {
			throw new NotFoundException(__('Invalid tipo foto'));
		}
		if ($this->request->is(array('post', 'put'))) {
			if ($this->TipoFoto->save($this->request->data)) {
				$this->Session->setFlash(__('The tipo foto has been saved.'));
				return $this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The tipo foto could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('TipoFoto.' . $this->TipoFoto->primaryKey => $id));
			$this->request->data = $this->TipoFoto->find('first', $options);
		}
	}

/**
 * admin_delete method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function admin_delete($id = null) {
		$this->TipoFoto->id = $id;
		if (!$this->TipoFoto->exists()) {
			throw new NotFoundException(__('Invalid tipo foto'));
		}
		$this->request->allowMethod('post', 'delete');
		if ($this->TipoFoto->delete()) {
			$this->Session->setFlash(__('The tipo foto has been deleted.'));
		} else {
			$this->Session->setFlash(__('The tipo foto could not be deleted. Please, try again.'));
		}
		return $this->redirect(array('action' => 'index'));
	}
}
