<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "empresa".
 *
 * @property integer $IdEmpresa
 * @property integer $IdRepresentanteLegal
 * @property string $ActividadEconomica
 * @property string $RazonSocial
 * @property string $Direccion
 * @property string $Telefonos
 * @property string $Emails
 * @property string $PaginaWeb
 * @property string $Nota
 * @property boolean $Activo
 * @property integer $IdCreadoPor
 * @property string $FechaCreacion
 * @property integer $IdModificadoPor
 * @property string $FechaModificacion
 *
 * @property Persona $idRepresentanteLegal
 * @property User $idCreadoPor
 * @property User $idModificadoPor
 * @property Proyecto[] $proyectos
 */
class Empresa extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'empresa';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['IdRepresentanteLegal', 'RazonSocial'], 'required'],
            [['IdRepresentanteLegal', 'IdCreadoPor', 'IdModificadoPor'], 'integer'],
            [['Nota'], 'string'],
            [['Activo'], 'boolean'],
            [['FechaCreacion', 'FechaModificacion'], 'safe'],
            [['ActividadEconomica'], 'string', 'max' => 150],
            [['RazonSocial', 'PaginaWeb'], 'string', 'max' => 100],
            [['Direccion', 'Telefonos', 'Emails'], 'string', 'max' => 255],
            [['IdRepresentanteLegal'], 'exist', 'skipOnError' => true, 'targetClass' => Persona::className(), 'targetAttribute' => ['IdRepresentanteLegal' => 'IdPersona']],
            [['IdCreadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdCreadoPor' => 'id']],
            [['IdModificadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdModificadoPor' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'IdEmpresa' => 'Id Empresa',
            'IdRepresentanteLegal' => 'Id Representante Legal',
            'ActividadEconomica' => 'Actividad Economica',
            'RazonSocial' => 'Razon Social',
            'Direccion' => 'Direccion',
            'Telefonos' => 'Telefonos',
            'Emails' => 'Emails',
            'PaginaWeb' => 'Pagina Web',
            'Nota' => 'Nota',
            'Activo' => 'Activo',
            'IdCreadoPor' => 'Id Creado Por',
            'FechaCreacion' => 'Fecha Creacion',
            'IdModificadoPor' => 'Id Modificado Por',
            'FechaModificacion' => 'Fecha Modificacion',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdRepresentanteLegal()
    {
        return $this->hasOne(Persona::className(), ['IdPersona' => 'IdRepresentanteLegal']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdCreadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdCreadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdModificadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdModificadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProyectos()
    {
        return $this->hasMany(Proyecto::className(), ['IdEmpresa' => 'IdEmpresa']);
    }
}
