<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "proyecto".
 *
 * @property integer $IdProyecto
 * @property string $NombreProyecto
 * @property integer $IdcEstadoProyecto
 * @property string $Latitud
 * @property string $Longitud
 * @property string $Descripcion
 * @property string $LinkExcel
 * @property integer $MapZoom
 * @property integer $IdCreadoPor
 * @property string $FechaCreacion
 * @property integer $IdModificadoPor
 * @property string $FechaModificacion
 *
 * @property Imagen[] $imagens
 * @property User $idCreadoPor
 * @property User $idModificadoPor
 * @property Clasificadorcomun $idcEstadoProyecto
 * @property Proyectodetalle[] $proyectodetalles
 */
class Proyecto extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'proyecto';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['NombreProyecto'], 'required'],
            [['IdcEstadoProyecto', 'MapZoom', 'IdCreadoPor', 'IdModificadoPor'], 'integer'],
            [['Latitud', 'Longitud'], 'number'],
            [['Descripcion'], 'string'],
            [['FechaCreacion', 'FechaModificacion'], 'safe'],
            [['NombreProyecto'], 'string', 'max' => 250],
            [['LinkExcel'], 'string', 'max' => 255],
            [['IdCreadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdCreadoPor' => 'id']],
            [['IdModificadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdModificadoPor' => 'id']],
            [['IdcEstadoProyecto'], 'exist', 'skipOnError' => true, 'targetClass' => Clasificadorcomun::className(), 'targetAttribute' => ['IdcEstadoProyecto' => 'IdClasificadorComun']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'IdProyecto' => 'Id Proyecto',
            'NombreProyecto' => 'Nombre Proyecto',
            'IdcEstadoProyecto' => 'Idc Estado Proyecto',
            'Latitud' => 'Latitud',
            'Longitud' => 'Longitud',
            'Descripcion' => 'Descripcion',
            'LinkExcel' => 'Link Excel',
            'MapZoom' => 'Map Zoom',
            'IdCreadoPor' => 'Id Creado Por',
            'FechaCreacion' => 'Fecha Creacion',
            'IdModificadoPor' => 'Id Modificado Por',
            'FechaModificacion' => 'Fecha Modificacion',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getImagens()
    {
        return $this->hasMany(Imagen::className(), ['IdProyecto' => 'IdProyecto']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdCreadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdCreadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdModificadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdModificadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdcEstadoProyecto()
    {
        return $this->hasOne(Clasificadorcomun::className(), ['IdClasificadorComun' => 'IdcEstadoProyecto']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProyectodetalles()
    {
        return $this->hasMany(Proyectodetalle::className(), ['IdProyecto' => 'IdProyecto']);
    }
}
